@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::InsertCommandOutput;
 
-our $DATE = '2014-12-12'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-01-25'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -17,6 +17,8 @@ with (
     },
 );
 
+has verbatim => (is => 'rw', default => sub{1});
+
 use namespace::autoclean;
 
 sub munge_files {
@@ -63,13 +65,14 @@ Dist::Zilla::Plugin::InsertCommandOutput - Insert the output of command into you
 
 =head1 VERSION
 
-This document describes version 0.02 of Dist::Zilla::Plugin::InsertCommandOutput (from Perl distribution Dist-Zilla-Plugin-InsertCommandOutput), released on 2014-12-12.
+This document describes version 0.03 of Dist::Zilla::Plugin::InsertCommandOutput (from Perl distribution Dist-Zilla-Plugin-InsertCommandOutput), released on 2015-01-25.
 
 =head1 SYNOPSIS
 
 In dist.ini:
 
  [InsertCommandOutput]
+ ;verbatim=1
 
 In your POD:
 
@@ -79,7 +82,8 @@ In your POD:
 
 This module finds C<# COMMAND: ...> directives in your POD, pass it to the
 Perl's backtick operator, and insert the result into your POD as a verbatim
-paragraph. If command fails (C<$?> is non-zero), build will be aborted.
+paragraph (unless when you set C<verbatim> to 0, in which case output will be
+inserted as-is). If command fails (C<$?> is non-zero), build will be aborted.
 
 =for Pod::Coverage .+
 
@@ -116,7 +120,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
